@@ -3,7 +3,7 @@ package Lemonldap::NG::Common::Module;
 use strict;
 use Mouse;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 # Object that provides loggers and error methods (typically PSGI object)
 has p => ( is => 'rw', weak_ref => 1 );
@@ -11,8 +11,9 @@ has p => ( is => 'rw', weak_ref => 1 );
 # Lemonldap::NG configuration hash ref
 has conf => ( is => 'rw', weak_ref => 1 );
 
-has logger     => ( is => 'rw', default => sub { $_[0]->{p}->logger } );
-has userLogger => ( is => 'rw', default => sub { $_[0]->{p}->userLogger } );
+has logger => ( is => 'rw', lazy => 1, default => sub { $_[0]->{p}->logger } );
+has userLogger =>
+  ( is => 'rw', lazy => 1, default => sub { $_[0]->{p}->userLogger } );
 
 sub error {
     my $self = shift;
